@@ -13,66 +13,61 @@
 """
 import logging
 from typing import Text
+from opensourcetest.interface.assertServer import AssertServer
+from opensourcetest.builtin.exceptions import *
 
 
-class AssertChecker:
+class AssertChecker(AssertServer):
 
-    @staticmethod
-    def assert_eq(response_value: Text, except_value: Text):
+    def assert_eq(self, response_value: Text, except_value: Text):
         logging.info(f"Assert EQ<equal>,Expected Value：{except_value},Response Data：{response_value}")
         try:
             assert Text(response_value) == Text(except_value)
         except AssertionError:
             logging.error(f"Assert EQ<equal> Fail,Expected Value：{except_value},Response Data：{response_value}")
-            raise AssertionError
+            raise AssertEqError
 
-    @staticmethod
-    def assert_gt(response_value: int, except_value: int):
+    def assert_gt(self, response_value: int, except_value: int):
         logging.info(f"Assert GT<greater than>,Expected Value：{except_value},Response Data：{response_value}")
         try:
             assert int(response_value) > int(except_value)
         except AssertionError:
             logging.error(f"Assert GT<greater than> Fail,Expected Value：{except_value},Response Data：{response_value}")
-            raise AssertionError
+            raise AssertGtError
 
-    @staticmethod
-    def assert_gte(response_value: int, except_value: int):
+    def assert_gte(self, response_value: int, except_value: int):
         logging.info(f"Assert GTE<gt equeal>,Expected Value：{except_value},Response Data：{response_value}")
         try:
             assert int(response_value) >= int(except_value)
         except AssertionError:
             logging.error(f"Assert GTE<gt equeal> Fail,Expected Value：{except_value},Response Data：{response_value}")
-            raise AssertionError
+            raise AssertGteError
 
-    @staticmethod
-    def assert_lt(response_value: int, except_value: int):
+    def assert_lt(self, response_value: int, except_value: int):
         logging.info(f"Assert LT<less than>,Expected Value：{except_value},Response Data：{response_value}")
         try:
             assert int(response_value) < int(except_value)
         except AssertionError:
             logging.error(f"Assert LT<less than> Fail,Expected Value：{except_value},Response Data：{response_value}")
-            raise AssertionError
+            raise AssertLtError
 
-    @staticmethod
-    def assert_lte(response_value: int, except_value: int):
+    def assert_lte(self, response_value: int, except_value: int):
         logging.info(f"Assert LTE<lt equal>,Expected Value：{except_value},Response Data：{response_value}")
         try:
             assert int(response_value) <= int(except_value)
         except AssertionError:
             logging.error(f"Assert LTE<lt equal> Fail,Expected Value：{except_value},Response Data：{response_value}")
-            raise AssertionError
+            raise AssertLteError
 
-    @staticmethod
-    def assert_ne(response_value: Text, except_value: Text):
+    def assert_ne(self, response_value: Text, except_value: Text):
         logging.info(f"Assert NE<not equal>,Expected Value：{except_value},Response Data：{response_value}")
         try:
             assert Text(response_value) != Text(except_value)
         except AssertionError:
             logging.error(f"Assert NE<not equal> Fail,Expected Value：{except_value},Response Data：{response_value}")
-            raise AssertionError
+            raise AssertNeError
 
-    @staticmethod
-    def assert_contain(response_value: Text, except_value: Text):
+    def assert_contain(self, response_value: Text, except_value: Text):
         logging.info(f"Assert CONTAIN<contain>,Expected Value：{except_value},Response Data：{response_value}")
         if except_value in response_value:
             assert True
@@ -82,4 +77,4 @@ class AssertChecker:
             except AssertionError:
                 logging.error(
                     f"Assert CONTAIN<contain> Fail,Expected Value：{except_value},Response Data：{response_value}")
-                raise AssertionError
+                raise AssertContainError
