@@ -17,15 +17,15 @@ import logging
 
 def log_output(ost_model, ost_type):
     """
-    Only used in console for request response httpmodel log output beautification
-    :param ost_model: OST request or response httpmodel
+    Only used in console for request response OST http model log output beautification
+    :param ost_model: OST request or response OST http model
     :param ost_type:OST type(request or response)
     :return:
     """
     msg = f"\n================== {ost_type} details ==================\n"
     for key, value in ost_model.dict().items():
         if isinstance(value, dict):
-            value = json.dumps(value, indent=4)
+            value = json.dumps(value, indent=4, ensure_ascii=False)
         msg += "{:<8} : {}\n".format(key, value)
     logging.info(msg)
 
