@@ -5,8 +5,8 @@
 ------------------------------------
 @Project : opensourcetest
 @Time    : 2020/12/30 17:28
-@Auth    : luozhongwen
-@Email   : luozw@inhand.com.cn
+@Auth    : chineseluo
+@Email   : 848257135@qq.com
 @File    : pictureOperation.py
 @IDE     : PyCharm
 ------------------------------------
@@ -14,10 +14,11 @@
 import logging
 import time
 import allure
+from typing import Text
 from opensourcetest.common.fileOperation import FileOption
 
 
-def screen_picture(driver):
+def screen_picture(driver) -> Text:
     logging.info("Screenshot operation in progress!")
     picture_time = time.strftime("%Y-%m-%d-%H_%M_%S", time.localtime(time.time()))
     file_path = "Report/picture"
