@@ -12,8 +12,9 @@ class TestLogin:
     @allure.severity("blocker")
     @allure.story("Test Login")
     @allure.title("test login")
-    def test_login(self):
-        params = {"username": "zouzou", "password": "zouzou"}
+    @pytest.mark.parametrize("username,password", [("zouzou", "zouzou"), ("zouzou1", "zouzou1")])
+    def test_login(self, username, password):
+        params = {"username": username, "password": password}
         result = start_run_case(Login, 0, ("status_code", 200, "GTE"), json=params)
         auth = {
             "Authorization": f'JWT {result["body"]["data"]["token"]}'
@@ -28,11 +29,10 @@ class TestLogin:
             "page": 1,
             "size": 20
         }
-        result = start_run_case(Login, "查询", session_connection=token, params=params)
-        logging.info(result)
+        start_run_case(Login, "查询", session_connection=token, params=params)
 
     @allure.severity("blocker")
     @allure.story("Test delete")
     @allure.title("test delete")
     def test_delete(self, token):
-        result = start_run_case(Login, "删除", session_connection=token, url_converter="58")
+        start_run_case(Login, "删除", session_connection=token, url_converter="58")
